@@ -1,11 +1,3 @@
-`evolve.brownian` <-
-function(phy,value=0,var=1) {
-	x <- as.vector(t(evolve.phylo(phy,value,var)$tip.character))
-	names(x) <- phy$tip.label
-	return(x)
-}
-
-
 `.evolve.trait` <-
 function(phy,
 	x.root=0, #root value
